***********************
The sherpa.image module
***********************

.. currentmodule:: sherpa.image

.. automodule:: sherpa.image

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      Image
      DataImage
      ModelImage
      ComponentModelImage
      SourceImage
      ComponentSourceImage
      RatioImage
      ResidImage
      PSFImage
      PSFKernelImage

Class Inheritance Diagram
=========================

.. inheritance-diagram::   Image DataImage ModelImage ComponentModelImage SourceImage ComponentSourceImage RatioImage ResidImage PSFImage PSFKernelImage
   :parts: 1
